ewa.config._config

Package ewa :: Module config :: Class _config |
[hide private]
[frames] | no frames]

# Class _config

source code

    object --+
             |
            _config

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
load(self, filename) | source code
merge_defaults(self, **kw) | source code
keys(self) | source code
__iter__(self) | source code
iteritems(self) | source code
clear(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)